==> keyclic_sdk_api-2.0.3%2B1.tar.gz: lib/model/operation_links_self_iri_template.dart <==
part of keyclic_sdk_api.api;

class OperationLinksSelfIriTemplate {
  OperationLinksSelfIriTemplate({
    this.mapping,
  });

  OperationLinksSelfIriTemplate.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    mapping = OperationLinksSelfIriTemplateMapping.fromJson(json['mapping']);
  }

  OperationLinksSelfIriTemplateMapping mapping;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is OperationLinksSelfIriTemplate &&
        runtimeType == other.runtimeType &&
        mapping == other.mapping;
  }

  /// By default hashCode return reference
  @override
  int get hashCode => 0 ^ mapping.hashCode;

  static List<OperationLinksSelfIriTemplate> listFromJson(List<dynamic> json) {
    return json == null
        ? <OperationLinksSelfIriTemplate>[]
        : json
            .map((value) => OperationLinksSelfIriTemplate.fromJson(value))
            .toList();
  }

  static Map<String, OperationLinksSelfIriTemplate> mapFromJson(
      Map<String, dynamic> json) {
    var map = Map<String, OperationLinksSelfIriTemplate>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = OperationLinksSelfIriTemplate.fromJson(value));
    }
    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      'mapping': mapping,
    };
  }

  @override
  String toString() {
    return 'OperationLinksSelfIriTemplate[mapping=$mapping, ]';
  }
}

==> keyclic_sdk_api-2.1.3%2B1.tar.gz: lib/model/operation_links_self_iri_template.dart <==
part of keyclic_sdk_api.api;

class OperationLinksSelfIriTemplate {
  OperationLinksSelfIriTemplate({
    this.mapping,
  });

  OperationLinksSelfIriTemplate.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    mapping = OperationLinksSelfIriTemplateMapping.fromJson(json['mapping']);
  }

  OperationLinksSelfIriTemplateMapping mapping;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is OperationLinksSelfIriTemplate &&
        runtimeType == other.runtimeType &&
        mapping == other.mapping;
  }

  /// By default hashCode return reference
  @override
  int get hashCode {
    int hashCode = 0;

    hashCode ^= mapping?.hashCode ?? 0;

    return hashCode;
  }

  static List<OperationLinksSelfIriTemplate> listFromJson(List<dynamic> json) {
    return json == null
        ? <OperationLinksSelfIriTemplate>[]
        : json
            .map((dynamic value) =>
                OperationLinksSelfIriTemplate.fromJson(value))
            .toList();
  }

  static Map<String, OperationLinksSelfIriTemplate> mapFromJson(
      Map<String, dynamic> json) {
    var map = Map<String, OperationLinksSelfIriTemplate>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = OperationLinksSelfIriTemplate.fromJson(value));
    }

    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      if (mapping != null) 'mapping': mapping,
    };
  }

  @override
  String toString() {
    return 'OperationLinksSelfIriTemplate[mapping=$mapping, ]';
  }
}
